/*
 *************************************************************************
 *                                                                       *
 * Copyright 2000 Compaq Computer Corporation                            *
 *                                                                       *
 * COMPAQ Registered in U.S. Patent and Trademark Office.                *
 *                                                                       *
 *************************************************************************
 * IMPORTANT: Carefully read the License Terms below before              *
 * proceeding.  By use of these materials you agree to these terms.      *
 * If you do not agree to these terms, you may not use this software or  *
 * the accompanying documentation.                                       *
 *************************************************************************
 * LICENSE TERMS                                                         *
 * 1. GRANT                                                              *
 * Compaq Computer Corporation ("COMPAQ") grants you the right to use,   *
 * modify, and distribute the following source code (the "Software")     *
 * on any number of computers. You may use the Software as part of       *
 * creating a software program or product intended for commercial or     *
 * non-commercial distribution in machine-readable source code, binary,  *
 * or executable formats. You may distribute the Software as             *
 * machine-readable source code provided this license is not removed     *
 * from the Software and any modifications are conspicuously indicated.  *
 * 2. COPYRIGHT                                                          *
 * The Software is owned by COMPAQ and its suppliers and is protected by *
 * copyright laws and international treaties.  Your use of the Software  *
 * and associated documentation is subject to the applicable copyright   *
 * laws and the express rights and restrictions of these terms.          *
 * 3. RESTRICTIONS                                                       *
 * You may not remove any copyright, trademark, or other proprietary     *
 * notices from the Software or the associated  documentation.           *
 * You are responsible for compliance with all applicable export or      *
 * re-export control laws and regulations if you export the Software.    *
 * This license is governed by and is to be construed under the laws     *
 * of the State of Texas.                                                *
 *                                                                       *
 * DISCLAIMER OF WARRANTY AND LIABILITY                                  *
 * Compaq shall not be liable for technical or editorial errors or       *
 * omissions contained herein. The information contained herein is       *
 * subject to change without notice.                                     *
 *                                                                       *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND.       *
 * THE ENTIRE RISK ARISING OUT OF THE USE OF THIS SOFTWARE REMAINS WITH  *
 * RECIPIENT.  IN NO EVENT SHALL COMPAQ BE LIABLE FOR ANY DIRECT,        *
 * CONSEQUENTIAL, INCIDENTAL, SPECIAL, PUNITIVE OR OTHER DAMAGES         *
 * WHATSOEVER (INCLUDING WITHOUT LIMITATION DAMAGES FOR LOSS OF BUSINESS *
 * PROFITS, BUSINESS INTERRUPTION, OR LOSS OF BUSINESS INFORMATION),     *
 * EVEN IF COMPAQ HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES    *
 * AND WHETHER IN AN ACTION OF CONTRACT OR TORT INCLUDING NEGLIGENCE.    *
 *                                                                       *
 * If you have any questions concerning this license, please contact:    *
 * Compaq Computer Corporation, Software Business Practices, ZKO1-2/D22, *
 * 110 Spit Brook Road, Nashua, NH. 03062-2698.                          *
 *                                                                       *
 *************************************************************************
 */

#include "vms_jackets.h"
#include <limits.h>
#include <pwd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <unixlib.h>


/*
** Much of the code I've seen expects the default directory spec that 
** comes back from getpwuid to be UNIX style, and the rest of the code
** won't object if it is. So, this jacket translates the default
** directory field (pw_dir) to UNIX format.
**
** Static storage is used in this routine and so it is not re-entrant.
** Hopefully this won't matter too much since the real getpwuid isn't
** re-entrant anyway. But we do have to make sure that the data
** returned is preserved until the next getpwuic call - this means we
** have to copy the result of decc$translate_vms.
*/

struct passwd getpwuid_passwd;
char getpwuid_vmsname[PATH_MAX+1];

struct passwd *GENERIC_GETPWUID_JACKET(uid_t uid)
{
    char *vmsdir;
    struct passwd *pwd;

    /*
    ** Call the regular getpwuid to retrieve the information.
    */
    pwd=getpwuid(uid);

    /*
    ** Did we get something?
    */
    if (pwd) {
	/*
	** Yes. so copy it to our private structure.
	*/
	memcpy(&getpwuid_passwd,pwd,sizeof(getpwuid_passwd));
	/*
	** Try to translate the directory name to UNIX format. If we
	** fail, then keep the original.
	*/
	vmsdir = decc$translate_vms(pwd->pw_dir);
	if (vmsdir) {
	    strcpy(getpwuid_vmsname,vmsdir);
	    getpwuid_passwd.pw_dir = getpwuid_vmsname;
	}
	/*
	** Return our private structure to the caller.
	*/
	return &getpwuid_passwd;
    }
    else
	return NULL;

}

#ifdef BUILD_GETPWUID_MAIN

/*
** Simple test program.
*/

int main (int argc, char *argv[])
{

    struct passwd *p;

    if (argc < 2 ) {
        printf("Usage is:\n\n");
        printf("  $ getpwuid uid\n");
        return 0;
    }

    p = GENERIC_GETPWUID_JACKET(atoi(argv[1]));
    if (p) {
	int uicg, uicm;
        uicg = (p->pw_uid & 0xFFFF0000) >> 16;
        uicm = (p->pw_uid & 0x0000FFFF);
        printf("  pw_name   %s\n", p->pw_name);
        printf("  pw_uid    %d ([%o,%o])\n", p->pw_uid,uicg,uicm);
        printf("  pw_gid    %d\n", p->pw_gid);
        printf("  pw_dir    %s\n", p->pw_dir);
        printf("  pw_shell  %s\n", p->pw_shell);
    }
    else
	perror("getpwuid");

    return 0;
}
#endif
