/*
 *************************************************************************
 *                                                                       *
 * Copyright 2000 Compaq Computer Corporation                            *
 *                                                                       *
 * COMPAQ Registered in U.S. Patent and Trademark Office.                *
 *                                                                       *
 *************************************************************************
 * IMPORTANT: Carefully read the License Terms below before              *
 * proceeding.  By use of these materials you agree to these terms.      *
 * If you do not agree to these terms, you may not use this software or  *
 * the accompanying documentation.                                       *
 *************************************************************************
 * LICENSE TERMS                                                         *
 * 1. GRANT                                                              *
 * Compaq Computer Corporation ("COMPAQ") grants you the right to use,   *
 * modify, and distribute the following source code (the "Software")     *
 * on any number of computers. You may use the Software as part of       *
 * creating a software program or product intended for commercial or     *
 * non-commercial distribution in machine-readable source code, binary,  *
 * or executable formats. You may distribute the Software as             *
 * machine-readable source code provided this license is not removed     *
 * from the Software and any modifications are conspicuously indicated.  *
 * 2. COPYRIGHT                                                          *
 * The Software is owned by COMPAQ and its suppliers and is protected by *
 * copyright laws and international treaties.  Your use of the Software  *
 * and associated documentation is subject to the applicable copyright   *
 * laws and the express rights and restrictions of these terms.          *
 * 3. RESTRICTIONS                                                       *
 * You may not remove any copyright, trademark, or other proprietary     *
 * notices from the Software or the associated  documentation.           *
 * You are responsible for compliance with all applicable export or      *
 * re-export control laws and regulations if you export the Software.    *
 * This license is governed by and is to be construed under the laws     *
 * of the State of Texas.                                                *
 *                                                                       *
 * DISCLAIMER OF WARRANTY AND LIABILITY                                  *
 * Compaq shall not be liable for technical or editorial errors or       *
 * omissions contained herein. The information contained herein is       *
 * subject to change without notice.                                     *
 *                                                                       *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND.       *
 * THE ENTIRE RISK ARISING OUT OF THE USE OF THIS SOFTWARE REMAINS WITH  *
 * RECIPIENT.  IN NO EVENT SHALL COMPAQ BE LIABLE FOR ANY DIRECT,        *
 * CONSEQUENTIAL, INCIDENTAL, SPECIAL, PUNITIVE OR OTHER DAMAGES         *
 * WHATSOEVER (INCLUDING WITHOUT LIMITATION DAMAGES FOR LOSS OF BUSINESS *
 * PROFITS, BUSINESS INTERRUPTION, OR LOSS OF BUSINESS INFORMATION),     *
 * EVEN IF COMPAQ HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES    *
 * AND WHETHER IN AN ACTION OF CONTRACT OR TORT INCLUDING NEGLIGENCE.    *
 *                                                                       *
 * If you have any questions concerning this license, please contact:    *
 * Compaq Computer Corporation, Software Business Practices, ZKO1-2/D22, *
 * 110 Spit Brook Road, Nashua, NH. 03062-2698.                          *
 *                                                                       *
 *************************************************************************
 */

#include "vms_jackets.h"
#include <stdio.h>
#include <fcntl.h>
#include <file.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include <errno.h>
#include <rmsdef.h>

/**********************************************************************/
/*  Jacket routines to handle VMS and decc limits                     */
/*                                                                    */
/*  Routine: GENERIC_UNLINK_JACKET                                    */
/*                                                                    */
/*  Jacket for: unlink                                                */
/*                                                                    */
/**********************************************************************/

int GENERIC_UNLINK_JACKET(const char *path_spec)
{
    char temp_string[TEMP_STRING_SIZE];
    char *new_path;
    int status;
    int save_errno; /* save the first time result*/
    int save_status;/* save the first time results and return those*/
    int fd;         /* just in case we unlink open file */

    new_path = GENERIC_VMS_Filename_parser((char *)path_spec,
                                           temp_string,
                                           GENERIC_K_STRING_TYPE_FILE,
                                           &status);
    GENERIC_TRACE("unlink_Jacket: Mapped:", path_spec, "To:", new_path);
    save_status = unlink(new_path);
    save_errno = errno;
    status = save_status;
    while(!status) /* there was a file, let's unlink until we get a bad status*/
	status = unlink(new_path); /* get rid of all version numbers */

    errno = save_errno; /* restore errno to the original errno, first time*/

    /* 
    ** When errno == EVMSERR it means a VMS-specific error has occured,
    ** something like trying to unlink an open file.  A perfectly normal
    ** activity on Unix, which means the file will be deleted when the
    ** last open reference is closed.  We gotta do it different on VMS
    */
    if ( errno == EVMSERR && vaxc$errno == RMS$_FLK ) {
	save_status = 0;
	/* note, we aint calling our open jacket here.  we already fixed up
	** the filename, hopefully anything else doesnt apply.  */
	fd = open( new_path, O_RDWR, 0, "fop=dlt", "shr=get,put" );
	close( fd );
    }

    return(save_status);
}
